@@ -4,10 +4,14 @@ from .FileIO import dump_json_file
 from .FileIO import load_csv_file 
 from .FileIO import dump_csv_file 
 from .videos import img_2_video
+from .dimensions import plot_tsne
+from .dimensions import plot_pca
 
 __all__ = [ 'load_json_file', 
             'dump_json_file', 
             'load_csv_file', 
             'dump_csv_file',
-            'img_2_video']
+            'img_2_video',
+            'plot_tsne',
+            'plot_pca']
 
